import { ChannelCard } from "@/components/cards/ChannelCard";
import { JsonCard } from "@/components/cards/JsonCard";
import { ServerCard } from "@/components/cards/ServerCard";
import { NavigationToolbar } from "@/components/common/NavigationToolbar";
import { fetchChannelById, fetchServerById } from "@/lib/db";
import { notFound } from "next/navigation";

export default async function Message({ params }: { params: { id: string } }) {
  const channel = await fetchChannelById(params.id);
  if (!channel) return notFound();

  const server =
    channel.channel_type === "TextChannel"
      ? await fetchServerById(channel.server)
      : undefined;

  return (
    <div className="flex flex-col gap-2">
      <NavigationToolbar>Inspecting Channel</NavigationToolbar>
      <ChannelCard channel={channel!} subtitle="Channel" />
      {server && <ServerCard server={server} subtitle="Server" />}
      <JsonCard obj={channel} />
    </div>
  );
}
