import { MessageContextCard } from "@/components/cards/MessageContextCard";
import { ReportCard } from "@/components/cards/ReportCard";
import { UserCard } from "@/components/cards/UserCard";
import { Badge } from "@/components/ui/badge";
import { buttonVariants } from "@/components/ui/button";
import {
  Card,
  CardDescription,
  CardHeader,
  CardTitle,
} from "@/components/ui/card";
import { Separator } from "@/components/ui/separator";
import {
  fetchReportById,
  fetchReports,
  fetchSnapshotsByReport,
  fetchUserById,
} from "@/lib/db";
import { ArrowLeft } from "lucide-react";
import Link from "next/link";
import { notFound } from "next/navigation";
import { Fragment } from "react";

export default async function Reports({ params }: { params: { id: string } }) {
  const report = await fetchReportById(params.id);
  if (!report) return notFound();

  const author = await fetchUserById(report.author_id);
  const snapshots = await fetchSnapshotsByReport(report._id);

  const relatedReports = await Promise.all(
    snapshots
      .map((snapshot) => snapshot._id)
      .map((contentId) =>
        fetchReports({
          _id: {
            $ne: report._id,
          },
          status: "Created",
          "content.id": contentId,
        })
      )
  );

  return (
    <div className="flex flex-col gap-2">
      <Link
        className={buttonVariants({ variant: "outline", size: "icon" })}
        href="/panel/reports"
      >
        <ArrowLeft className="h-4 w-4" />
      </Link>

      <Card className="shadow-none">
        <CardHeader>
          <CardTitle className="overflow-ellipsis whitespace-nowrap overflow-x-clip flex gap-2 items-center">
            {report.content.report_reason.includes("Illegal") && (
              <Badge variant="destructive">Urgent</Badge>
            )}{" "}
            {report.additional_context || "No reason specified"}
          </CardTitle>
          <CardDescription>
            {report._id.toString().substring(20, 26)} &middot;{" "}
            {report.content.report_reason} &middot; {report.content.type}
          </CardDescription>
        </CardHeader>
      </Card>
      <UserCard user={author!} subtitle="Report Author" />

      {snapshots.map((snapshot, index) => (
        <Fragment key={snapshot._id}>
          <Separator className="my-2" />
          <div className="flex gap-2">
            <div className="flex-[2]">
              {relatedReports[index].length ? (
                <h2 className="text-md pb-2">&nbsp;</h2>
              ) : undefined}
              {snapshot._type === "Message" && (
                <MessageContextCard snapshot={snapshot} />
              )}
            </div>
            {relatedReports[index].length ? (
              <div className="flex-1">
                <h2 className="text-md text-center pb-2">Other Reports</h2>
                {relatedReports[index].map((relatedReport) => (
                  <ReportCard key={relatedReport._id} report={relatedReport} />
                ))}
              </div>
            ) : undefined}
          </div>
        </Fragment>
      ))}
    </div>
  );
}
